Method: Backup::Storage::RSync#ssh_user

Defined in:
lib/backup/storage/rsync.rb

#ssh_userObject

SSH User

If the user running the backup is not the same user that needs to authenticate with the remote server, specify the user here.

The user must have SSH keys setup for passphrase-less access to the remote. If the SSH User does not have passphrase-less keys, or no default keys in their ‘~/.ssh` directory, you will need to use the -i option in :additional_ssh_options to specify the passphrase-less key to use.

Used only for :ssh and :ssh_daemon modes.



55
56
57
# File 'lib/backup/storage/rsync.rb', line 55

def ssh_user
  @ssh_user
end